# ResourceSpec

The configurable properties of a Resource. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The human readable name of the resource. Names are unique for a given resource type within an organisation.  | 
**resource_type** | **str** | The type of the resource. Resources of different types service different purposes, and have different behaviour. - An &#x60;application&#x60; provides high level functionality such as a website. Its fine-grained   permissions are configured on a per-application basis. It corresponds to an &#x60;Application&#x60;   resource. - A &#x60;fileshare&#x60; exposes a directory to the internet for file sharing purposes. Its permission model is fixed. It corresponds to a FileShareService resource. - An &#x60;ip_service&#x60; exposes an IP based service to the internet. Its permission model is fixed. It corresponds to an ApplicationService resource.  | 
**org_id** | **str** | The unique ID of the organisation which owns this Resource. | 
**name_slug** | **str** | A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


